summaryrefslogtreecommitdiffstats
path: root/vcs/cvsservice/cvspart.h
diff options
context:
space:
mode:
Diffstat (limited to 'vcs/cvsservice/cvspart.h')
-rw-r--r--vcs/cvsservice/cvspart.h7
1 files changed, 4 insertions, 3 deletions
diff --git a/vcs/cvsservice/cvspart.h b/vcs/cvsservice/cvspart.h
index b774d682..886d13b2 100644
--- a/vcs/cvsservice/cvspart.h
+++ b/vcs/cvsservice/cvspart.h
@@ -37,20 +37,21 @@ class CvsServicePartImpl;
class CvsServicePart : public KDevVersionControl
{
Q_OBJECT
+ TQ_OBJECT
friend class CvsServicePartImpl;
public:
//! Standard constructor.
- CvsServicePart( TQObject *parent, const char *name, const TQStringList & );
+ CvsServicePart( TQObject *tqparent, const char *name, const TQStringList & );
//! Destructor.
virtual ~CvsServicePart();
/**
* Returns the configuration widget (for properly configuring the project to
* use CVS), child of @p parent.
*/
- virtual TQWidget *newProjectWidget( TQWidget *parent );
+ virtual TQWidget *newProjectWidget( TQWidget *tqparent );
/**
* Setup a directory tree for use with CVS.
*/
@@ -37,20 +37,21 @@ class CvsServicePartImpl;
/**
* Returns the configuration widget (for properly configuring the project to
- * use CVS), child of @p parent.
+ * use CVS), child of @p tqparent.
*/